@@ -87,7 +87,7 @@ API_PATH = {
     "parts_bulk_create": "/api/v3/parts/bulk_create_part_instances",
     "parts_bulk_delete": "/api/v3/parts/bulk_delete_part_instances",
     "parts_export": "api/v3/parts/export",
-    'parts_import': 'api/v3/parts/import_parts',
+    "parts_import": "api/v3/parts/import_parts",
     "part": "api/v3/parts/{part_id}.json",
     "order_properties": "api/v3/parts/{part_id}/order_properties",
     "properties": "api/v3/properties.json",
