@@ -6,11 +6,7 @@ from urllib.parse import urljoin
 
 import requests
 
-from pykechain.defaults import (
-    API_EXTRA_PARAMS,
-    ASYNC_REFRESH_INTERVAL,
-    ASYNC_TIMEOUT_LIMIT,
-)
+from pykechain.defaults import API_EXTRA_PARAMS, ASYNC_REFRESH_INTERVAL, ASYNC_TIMEOUT_LIMIT
 from pykechain.enums import (
     ActivityClassification,
     ActivityRootNames,
@@ -1249,12 +1245,13 @@ class Activity(TreeObject, TagsMixin):
             current one
         :raises APIError: When the call is unsuccessful, for example when cloning cross-forms
         """
-        url = self._client._build_url("clone_widgets",
-                                      activity_from_id=self.id,
-                                      activity_to_id=from_activity.id)
+        url = self._client._build_url(
+            "clone_widgets", activity_from_id=self.id, activity_to_id=from_activity.id
+        )
 
         response = self._client._request(
-            "POST", url,
+            "POST",
+            url,
         )
 
         if response.status_code != requests.codes.ok:  # pragma: no cover
