@@ -1,19 +1,19 @@
 import os
 from datetime import datetime
-
-import requests
 from typing import Dict, Optional, Union
 
+import requests
+
 from pykechain.enums import (
-    ServiceScriptUser,
-    ServiceExecutionStatus,
-    ServiceType,
     ServiceEnvironmentVersion,
+    ServiceExecutionStatus,
+    ServiceScriptUser,
+    ServiceType,
 )
 from pykechain.exceptions import APIError
 from pykechain.models.base import Base, BaseInScope
-from pykechain.models.input_checks import check_text, check_enum, check_type
-from pykechain.utils import parse_datetime, Empty, clean_empty_values, empty
+from pykechain.models.input_checks import check_enum, check_text, check_type
+from pykechain.utils import Empty, clean_empty_values, empty, parse_datetime
 
 
 class Service(BaseInScope):
