@@ -6,8 +6,4 @@ from pykechain.models.sidebar.sidebar_button import SideBarButton
 from pykechain.models.sidebar.sidebar_card import SideBarCard
 from pykechain.models.sidebar.sidebar_manager import SideBarManager
 
-__all__ = (
-    "SideBarManager",
-    "SideBarButton",
-    "SideBarCard"
-)
+__all__ = ("SideBarManager", "SideBarButton", "SideBarCard")
