@@ -1,21 +1,21 @@
 from collections.abc import Iterable
-from typing import Any, Optional, List, Dict
+from typing import Any, Dict, List, Optional
 
 from pykechain.enums import (
-    SidebarType,
-    URITarget,
-    SubprocessDisplayMode,
-    KEChainPages,
-    KEChainPageLabels,
     KEChainPageIcons,
+    KEChainPageLabels,
+    KEChainPages,
+    SidebarType,
+    SubprocessDisplayMode,
+    URITarget,
 )
 from pykechain.exceptions import NotFoundError
 from pykechain.models.input_checks import (
-    check_url,
-    check_text,
     check_enum,
     check_list_of_dicts,
+    check_text,
     check_type,
+    check_url,
 )
 from pykechain.models.sidebar.sidebar_base import SideBarItem
 from pykechain.models.sidebar.sidebar_button import SideBarButton
