@@ -1,28 +1,28 @@
 """Widgets for KE-chain 3."""
 from .widget import Widget  # noqa: F403,F401,D104
 from .widget_models import (
-    MetapanelWidget,
-    PropertygridWidget,
-    UndefinedWidget,
-    FilteredgridWidget,
-    SupergridWidget,
     AttachmentviewerWidget,
-    TasknavigationbarWidget,
-    HtmlWidget,
-    ServiceWidget,
-    NotebookWidget,
-    JsonWidget,
-    MulticolumnWidget,
-    ProgressWidget,
-    ScopeWidget,
-    ThirdpartyWidget,
-    SignatureWidget,
     CardWidget,
-    ServicecardWidget,
     DashboardWidget,
-    TasksWidget,
+    FilteredgridWidget,
+    HtmlWidget,
+    JsonWidget,
+    MetapanelWidget,
+    MulticolumnWidget,
+    NotebookWidget,
+    ProgressWidget,
+    PropertygridWidget,
     ScopemembersWidget,
-    WeatherWidget
+    ScopeWidget,
+    ServicecardWidget,
+    ServiceWidget,
+    SignatureWidget,
+    SupergridWidget,
+    TasknavigationbarWidget,
+    TasksWidget,
+    ThirdpartyWidget,
+    UndefinedWidget,
+    WeatherWidget,
 )
 from .widgets_manager import WidgetsManager
 
